@@ -4,7 +4,7 @@ import xml.etree.ElementTree as ET
 from PyQt5.QtCore import QDir, Qt, QObject, pyqtSignal
 from PyQt5.QtWidgets import QMessageBox, QApplication
 
-from urh import constants
+from urh import settings
 from urh.dev import config
 from urh.models.ProtocolTreeItem import ProtocolTreeItem
 from urh.signalprocessing.Encoding import Encoding
@@ -118,27 +118,27 @@ class ProjectManager(QObject):
         if self.project_file:
             return
         else:
-            prefix = os.path.realpath(os.path.join(constants.SETTINGS.fileName(), ".."))
+            prefix = os.path.realpath(os.path.join(settings.get_qt_settings_filename(), ".."))
 
         fallback = [Encoding(["Non Return To Zero (NRZ)"]),
 
-                    Encoding(["Non Return To Zero Inverted (NRZ-I)",
-                              constants.DECODING_INVERT]),
+                    Encoding(["Non Return To Zero + Invert",
+                              settings.DECODING_INVERT]),
 
                     Encoding(["Manchester I",
-                              constants.DECODING_EDGE]),
+                              settings.DECODING_EDGE]),
 
                     Encoding(["Manchester II",
-                              constants.DECODING_EDGE,
-                              constants.DECODING_INVERT]),
+                              settings.DECODING_EDGE,
+                              settings.DECODING_INVERT]),
 
                     Encoding(["Differential Manchester",
-                              constants.DECODING_EDGE,
-                              constants.DECODING_DIFFERENTIAL])
+                              settings.DECODING_EDGE,
+                              settings.DECODING_DIFFERENTIAL])
                     ]
 
         try:
-            f = open(os.path.join(prefix, constants.DECODINGS_FILE), "r")
+            f = open(os.path.join(prefix, settings.DECODINGS_FILE), "r")
         except FileNotFoundError:
             self.decodings = fallback
             return
@@ -159,6 +159,9 @@ class ProjectManager(QObject):
             return
 
         for dev_tag in tag:
+            if dev_tag.text is None:
+                logger.warn("{} has None text".format(str(dev_tag)))
+                continue
             try:
                 try:
                     value = int(dev_tag.text)
@@ -166,7 +169,11 @@ class ProjectManager(QObject):
                     value = float(dev_tag.text)
             except ValueError:
                 value = dev_tag.text
-            target_dict[dev_tag.tag] = value
+
+            if dev_tag.tag == "bit_len":
+                target_dict["samples_per_symbol"] = value   # legacy
+            else:
+                target_dict[dev_tag.tag] = value
 
     @staticmethod
     def __device_conf_dict_to_xml(key_name: str, device_conf: dict):
@@ -209,7 +216,7 @@ class ProjectManager(QObject):
         FileOperator.RECENT_PATH = path
         util.PROJECT_PATH = path
         self.project_path = path
-        self.project_file = os.path.join(self.project_path, constants.PROJECT_FILE)
+        self.project_file = os.path.join(self.project_path, settings.PROJECT_FILE)
         collapse_project_tabs = False
         if not os.path.isfile(self.project_file):
             if ask_for_new_project:
@@ -280,7 +287,7 @@ class ProjectManager(QObject):
         self.project_updated.emit()
 
     def convert_folder_to_project(self):
-        self.project_file = os.path.join(self.project_path, constants.PROJECT_FILE)
+        self.project_file = os.path.join(self.project_path, settings.PROJECT_FILE)
         self.main_controller.show_project_settings()
 
     def write_signal_information_to_project_file(self, signal: Signal, tree=None):
@@ -311,8 +318,9 @@ class ProjectManager(QObject):
 
         signal_tag.set("name", signal.name)
         signal_tag.set("filename", file_path)
-        signal_tag.set("bit_length", str(signal.bit_len))
-        signal_tag.set("qad_center", str(signal.qad_center))
+        signal_tag.set("samples_per_symbol", str(signal.samples_per_symbol))
+        signal_tag.set("center", str(signal.center))
+        signal_tag.set("center_spacing", str(signal.center_spacing))
         signal_tag.set("tolerance", str(signal.tolerance))
         signal_tag.set("noise_threshold", str(signal.noise_threshold))
         signal_tag.set("noise_minimum", str(signal.noise_min_plot))
@@ -321,6 +329,8 @@ class ProjectManager(QObject):
         signal_tag.set("sample_rate", str(signal.sample_rate))
         signal_tag.set("pause_threshold", str(signal.pause_threshold))
         signal_tag.set("message_length_divisor", str(signal.message_length_divisor))
+        signal_tag.set("bits_per_symbol", str(signal.bits_per_symbol))
+        signal_tag.set("costas_loop_bandwidth", str(signal.costas_loop_bandwidth))
 
         messages = ET.SubElement(signal_tag, "messages")
         for message in messages:
@@ -481,13 +491,24 @@ class ProjectManager(QObject):
         for sig_tag in root.iter("signal"):
             if sig_tag.attrib["filename"] == signal_filename:
                 signal.name = sig_tag.attrib["name"]
-                signal.qad_center = float(sig_tag.get("qad_center", 0))
+                center = sig_tag.get("qad_center", None)  # legacy support
+                signal.center = float(sig_tag.get("center", 0)) if center is None else float(center)
+                signal.center_spacing = float(sig_tag.get("center_spacing", 0.1))
                 signal.tolerance = int(sig_tag.get("tolerance", 5))
+                signal.bits_per_symbol = int(sig_tag.get("bits_per_symbol", 1))
+                signal.costas_loop_bandwidth = float(sig_tag.get("costas_loop_bandwidth", 0.1))
 
                 signal.noise_threshold = float(sig_tag.get("noise_threshold", 0.1))
                 signal.sample_rate = float(sig_tag.get("sample_rate", 1e6))
-                signal.bit_len = int(sig_tag.get("bit_length", 100))
-                signal.modulation_type = int(sig_tag.get("modulation_type", 0))
+                signal.samples_per_symbol = int(sig_tag.get("bit_length", 0))   # Legacy for old project files
+                if signal.samples_per_symbol == 0:
+                    signal.samples_per_symbol = int(sig_tag.get("samples_per_symbol", 100))
+
+                try:
+                    # Legacy support when modulation type was integer
+                    signal.modulation_type = Signal.MODULATION_TYPES[int(sig_tag.get("modulation_type", 0))]
+                except (ValueError, IndexError):
+                    signal.modulation_type = sig_tag.get("modulation_type", "ASK")
                 signal.pause_threshold = int(sig_tag.get("pause_threshold", 8))
                 signal.message_length_divisor = int(sig_tag.get("message_length_divisor", 1))
                 break
@@ -548,7 +569,7 @@ class ProjectManager(QObject):
 
     def from_dialog(self, dialog):
         if dialog.committed:
-            if dialog.new_project or not os.path.isfile(os.path.join(dialog.path, constants.PROJECT_FILE)):
+            if dialog.new_project or not os.path.isfile(os.path.join(dialog.path, settings.PROJECT_FILE)):
                 self.set_project_folder(dialog.path, ask_for_new_project=False, close_all=False)
             self.device_conf["frequency"] = dialog.freq
             self.device_conf["sample_rate"] = dialog.sample_rate
